DeclarativeMdxConfiguration class

Constructors

DeclarativeMdxConfiguration({WorkflowPage? page, Workflow? workflow, Map<String, dynamic>? workflowJson, String? workflowJsonString, String? workflowUrl})

Properties

hashCode int
The hash code for this object.
no setterinherited
page WorkflowPage?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
workflow Workflow?
final
workflowJson Map<String, dynamic>?
final
workflowJsonString String?
final
workflowUrl String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited