CustomNode class

Inheritance
  • Object
  • SpanNode
  • ElementNode
  • CustomNode

Constructors

CustomNode({ModelStateProvider? modelProvider, List<TagHandler>? tagHandlers, required String text, required MarkdownConfig config})

Properties

children List<SpanNode>
finalinherited
childrenSpan TextSpan
no setterinherited
config → MarkdownConfig
final
customAttributes Map<String, String>?
getter/setter pair
customContent String?
getter/setter pair
customTag String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
modelProvider ModelStateProvider?
final
parent → SpanNode?
no setterinherited
parentStyle TextStyle?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style TextStyle?
getter/setter pairinherited
tagHandlers List<TagHandler>?
final
text String
final

Methods

accept(SpanNode? node) → void
use accept to add a child
inherited
attributesFromText(String tag, String parseTarget) Map<String, String>
build() InlineSpan
override
contentFromText(String tag, String parseTarget) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAccepted(SpanNode parent) → void
when this node was accepted by it's parent, onAccepted will be triggered
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited