Customizations class
- Inheritance
-
- Object
- WorkflowPageStyle
- WorkflowStepStyle
- Customizations
Constructors
-
Customizations({required List<
TagHandler> customComponents, Widget headerBuilder()?, bool? hideHeader, Widget containerBuilder(BuildContext context, Widget pageContent)?, StyledTypography? typography, ListMarker? listMarker})
Properties
- containerBuilder → Widget Function(BuildContext context, Widget pageContent)?
-
finalinherited
-
customComponents
↔ List<
TagHandler> -
getter/setter pair
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerBuilder → Widget Function()?
-
finalinherited
-
finalinherited
- hideHeader → bool?
-
finalinherited
- listMarker → ListMarker?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stepDividerBuilder → Widget Function()?
-
finalinherited
- stepLabelBuilder → Widget Function()?
-
finalinherited
- typography → StyledTypography?
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited