StyledWorkflowPage class
- Implementers
Constructors
- StyledWorkflowPage({Widget containerBuilder(BuildContext context, Widget pageContent)?, StyledTypography? typography, ListMarker? listMarker})
Properties
- containerBuilder → Widget Function(BuildContext context, Widget pageContent)?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- listMarker → ListMarker?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- typography → StyledTypography?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited