Workflow class

Constructors

Workflow({required List<WorkflowStep> steps, VoidCallback? onCancelled, VoidCallback? onComplete})

Properties

hashCode int
The hash code for this object.
no setterinherited
onCancelled VoidCallback?
final
onComplete VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
steps List<WorkflowStep>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> workflowJson) Workflow?