WorkflowPage class
Constructors
-
WorkflowPage({String? content, Future<
String> contentLoader()?, WorkflowPageStyle? style})
Properties
- content → String?
-
final
-
contentLoader
→ Future<
String> Function()? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → WorkflowPageStyle?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited