WorkflowStatus class

Constructors

WorkflowStatus({required List<WorkflowAction> actions, required WorkflowPageStatus pageStatus, required List<WorkflowStepInfo> steps})

Properties

actions List<WorkflowAction>
final
hashCode int
The hash code for this object.
no setterinherited
pageStatus WorkflowPageStatus
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
steps List<WorkflowStepInfo>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited