WorkflowStep class

Constructors

WorkflowStep({required List<WorkflowPage> pages, String? label, StyledWorkflowStep? style})

Properties

hashCode int
The hash code for this object.
no setterinherited
label String?
final
pages List<WorkflowPage>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style StyledWorkflowStep?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited