WorkflowStepInfo class

Constructors

WorkflowStepInfo(int index, String? label, int pageCount, bool isActive)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
final
isActive bool
final
label String?
final
pageCount int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited