WorkflowStepStyle class
- Inheritance
-
- Object
- WorkflowPageStyle
- WorkflowStepStyle
- Implementers
Constructors
- WorkflowStepStyle({Widget headerBuilder()?, bool? hideHeader, Widget stepDividerBuilder()?, Widget stepLabelBuilder()?, Widget containerBuilder(BuildContext context, Widget pageContent)?, StyledTypography? typography, ListMarker? listMarker})
Properties
- containerBuilder → Widget Function(BuildContext context, Widget pageContent)?
-
finalinherited
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerBuilder → Widget Function()?
-
final
-
final
- hideHeader → bool?
-
final
- listMarker → ListMarker?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stepDividerBuilder → Widget Function()?
-
final
- stepLabelBuilder → Widget Function()?
-
final
- typography → StyledTypography?
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited